import 'package:flutter/material.dart';
import 'package:flutter_widget_from_html/flutter_widget_from_html.dart';
import 'package:mypoint_flutter_app/extensions/date_format.dart';
import 'package:mypoint_flutter_app/extensions/num_extension.dart';
import 'package:mypoint_flutter_app/extensions/string_extension.dart';
import '../../../widgets/back_button.dart';
import '../models/product_model.dart';
import 'voucher_detail_viewmodel.dart';
import 'package:get/get.dart';

class VoucherDetailScreen extends StatefulWidget {
  const VoucherDetailScreen({super.key});

  @override
  _VoucherDetailScreenState createState() => _VoucherDetailScreenState();
}

class _VoucherDetailScreenState extends State<VoucherDetailScreen> {
  late final int productId;
  late final VoucherDetailViewModel _viewModel;

  @override
  void initState() {
    super.initState();
    final args = Get.arguments;
    if (args is int) {
      productId = args;
    } else if (args is Map) {
      productId = args['productId'];
    }
    _viewModel = Get.put(VoucherDetailViewModel(productId: productId));
    _viewModel.getProductDetail();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Obx(() {
        if (_viewModel.isLoading.value) {
          return const Center(child: CircularProgressIndicator());
        }
        final product = _viewModel.product.value;
        if (product == null) {
          return const Center(child: Text("Không tìm thấy sản phẩm"));
        }
        return Stack(
          children: [
            SingleChildScrollView(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  _buildHeader(product),
                  _buildInfo(product),
                  _buildDetailBlock(product),
                  _buildConditionBlock(product),
                ],
              ),
            ),
            SafeArea(
              child: Padding(
                padding: const EdgeInsets.all(8),
                child: CustomBackButton(),
              ),
            ),
          ],
        );
      }),
    );
  }

  Widget _buildHeader(ProductModel product) {
    return AspectRatio(
      aspectRatio: 16 / 9,
      child: Image.network(
        product.banner?.url ?? '',
        fit: BoxFit.cover,
        errorBuilder: (_, __, ___) => Image.asset('assets/images/sample.png', fit: BoxFit.cover),
      ),
    );
  }

  Widget _buildInfo(ProductModel product) {
    return Container(
      padding: const EdgeInsets.all(16),
      decoration: const BoxDecoration(
        color: Colors.white,
        borderRadius: BorderRadius.vertical(top: Radius.circular(16)),
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(product.content?.name ?? '', style: const TextStyle(fontSize: 20, fontWeight: FontWeight.bold)),
          const SizedBox(height: 8),
          Row(
            children: [
              const Text('Hạn dùng: ', style: TextStyle(color: Colors.grey)),
              Text(product.expire ?? "", style: const TextStyle(color: Colors.red)),
            ],
          ),
          if (!(product.inStock ?? true))
            Container(
              margin: const EdgeInsets.only(top: 8),
              padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 4),
              decoration: BoxDecoration(color: Colors.grey.shade300, borderRadius: BorderRadius.circular(8)),
              child: const Text('Tạm hết', style: TextStyle(color: Colors.red)),
            ),
          const Divider(height: 24),
          Row(
            children: [
              CircleAvatar(
                radius: 16,
                backgroundImage: NetworkImage(product.brand?.logo ?? ''),
                backgroundColor: Colors.transparent,
              ),
              const SizedBox(width: 8),
              Expanded(
                child: Text(product.brand?.name ?? '', style: const TextStyle(fontSize: 14)),
              ),
              _buildPointTag(product),
            ],
          )
        ],
      ),
    );
  }

  Widget _buildPointTag(ProductModel product) {
    final priceText = product.amountToBePaid?.money() ?? "";
    final isFree = (product.price?.value ?? 0) == 0;
    return Container(
      padding: const EdgeInsets.symmetric(horizontal: 8, vertical: 2),
      decoration: BoxDecoration(
        color: isFree ? Colors.orange.shade50 : Colors.red.shade100,
        borderRadius: BorderRadius.circular(12),
      ),
      child: Row(
        mainAxisSize: MainAxisSize.min,
        children: [
          Image.asset('assets/images/ic_point.png', width: 20, height: 20),
          const SizedBox(width: 4),
          Text(
            priceText,
            style: TextStyle(
              fontSize: 12,
              color: isFree ? Colors.orange : Colors.red,
              fontWeight: FontWeight.w500,
            ),
          ),
        ],
      ),
    );
  }

  Widget _buildDetailBlock(ProductModel product) {
    return _buildTextBlock("Chi tiết ưu đãi", product.content?.detail);
  }

  Widget _buildConditionBlock(ProductModel product) {
    return _buildTextBlock("Điều kiện áp dụng", product.content?.termAndCondition);
  }

  Widget _buildTextBlock(String title, String? content) {
    if (content == null || content.isEmpty) return const SizedBox();
    return Padding(
      padding: const EdgeInsets.fromLTRB(16, 12, 16, 0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(title, style: const TextStyle(fontSize: 16, fontWeight: FontWeight.bold)),
          const SizedBox(height: 8),
          HtmlWidget(content),
        ],
      ),
    );
  }
}
